MLECO-2723: Updating RNNoise to use 512 frame size

* CMSIS-DSP acceleration will now be used for FFT in RNNoise pre-processing
* PESQ scores tested and similar

Signed-off-by: Richard Burton <richard.burton@arm.com>
Change-Id: Ifeebc041f58867909b27c948950e08f8f39ef276
diff --git a/tests/use_case/noise_reduction/RNNNoiseUCTests.cc b/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
index d57fced..c2b7ffb 100644
--- a/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
+++ b/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
@@ -23,7 +23,7 @@
 #include <catch.hpp>
 #include <hal.h>
 #include <Profiler.hpp>
-#include <iostream>
+
 #define PLATFORM \
 hal_platform    platform; \
 data_acq_module data_acq; \
@@ -177,8 +177,8 @@
             std::vector<int16_t> runtime(g_FrameLength);
             std::memcpy(runtime.data(), &memDump[startOfLastInfOut], oneInferenceOutSizeBytes);
 
-            /* Margin of 22 is 0.03% error. */
-            REQUIRE_THAT(golden, Catch::Matchers::Approx(runtime).margin(22));
+            /* Margin of 43 is 0.07% error. */
+            REQUIRE_THAT(golden, Catch::Matchers::Approx(runtime).margin(43));
         }
         ++infIndex;
     }